function onSubmitPhonebook() {
    if (document.getElementById("phonebook_manual_input").checked) {
        if (document.getElementById("phonebook_entries_table").tBodies[0].rows.length < 100) {
            var newEntryName = document.getElementById("phonebook_new_entry_name");
            var newEntrySite = document.getElementById("phonebook_new_entry_site");
            var newEntryBuilding = document.getElementById("phonebook_new_entry_building");
            var newEntryFloor = document.getElementById("phonebook_new_entry_floor");
            var newEntryRoom = document.getElementById("phonebook_new_entry_room");
            if (newEntryName.value && newEntryName.value.trim()
                    && checkEntryDataValidity(parseInt(newEntrySite.value), parseInt(newEntryBuilding.value), parseInt(newEntryFloor.value), parseInt(newEntryRoom.value))) {
                onSubmit();
            } else {
                alert("Invalid entry - ensure all parameters are valid");
            }
        } else {
            alert("Max number of entries reached - delete one or more entries to add a new entry");
        }
    } else {
        const input = document.getElementById("phonebook_csv_file_input").files[0];
        if (input == null) {
            return;
        }

        const reader = new FileReader();
        reader.onload = function (e) {
            const text = e.target.result;
            if (parsePhonebookEntries(text)) {
                onSubmit();
            } else {
                alert("No valid entries found - check csv entry format");
                // Force reload to allow re-upload of csv file
                document.getElementById("form").submit();
            }
        }

        reader.readAsText(input);
    }
}

function editItem(index) {
    var editCell = document.getElementById("edit_" + index);
    var nameElement = document.getElementById("entry_name_" + index);
    var siteElement = document.getElementById("entry_site_" + index);
    var buildingElement = document.getElementById("entry_building_" + index);
    var floorElement = document.getElementById("entry_floor_" + index);
    var roomElement = document.getElementById("entry_room_" + index);

    var site = parseInt(siteElement.value);
    var building = parseInt(buildingElement.value);
    var floor = parseInt(floorElement.value);
    var room = parseInt(roomElement.value);

    if (editCell.src.includes("save.png")) {
        if (checkEntryDataValidity(site, building, floor, room)) {
            document.getElementById("phonebook_edit_entry_index").value = index;
            document.getElementById("phonebook_edit_entry_name").value = nameElement.value;
            document.getElementById("phonebook_edit_entry_id").value = convertDataToId(site, building, floor, room);
            document.getElementById("phonebook_edit_entry_use_expanded_format").value = building >= 100 ? 1 : 0
            onSubmit();
        } else {
            alert("Error saving settings - check form input")
        }
    } else {
        nameElement.disabled = false;
        siteElement.disabled = false;
        buildingElement.disabled = false;
        floorElement.disabled = false;
        roomElement.disabled = false;
        editCell.src = "../images/save.png";
    }
}

function deleteItem(entryName) {
    if (confirm("Are you sure you want to delete \"" + entryName + "\"?")) {
        document.getElementById("phonebook_delete_entry").value = entryName;
        onSubmit();
    }
}
function updateInputType(element) {
    var csvFileElement = document.getElementById("phonebook_csv_file_input");
    var newEntryElement = document.getElementById("phonebook_new_entry_table");
    if (element.id == "phonebook_file_input") {
        csvFileElement.hidden = false;
        newEntryElement.hidden = true;
        document.getElementById("phonebook_manual_input").checked = false;
    } else {
        csvFileElement.hidden = true;
        newEntryElement.hidden = false;
        document.getElementById("phonebook_file_input").checked = false;
    }
}

function parsePhonebookEntries(entries) {
    var firstRowPos = entries.indexOf("\n");
    if (firstRowPos == -1) {
        // Allow empty file to enable wiping of entry list
        document.getElementById("phonebook_save_enabled").checked = 1;
        return true;
    }

    const sliced = entries.slice(firstRowPos + 1);
    const rows = sliced.split("\n");
    if (rows.length == 0 || !rows[0]) {
        // Allow empty file to enable wiping of entry list
        document.getElementById("phonebook_save_enabled").checked = 1;
        return true;
    }

    var validEntryCount = 0;
    for (var i = 0; i < rows.length && validEntryCount < 100; i++) {
        const values = rows[i].split(",");
        if (values.length != 5) {
            continue;
        }

        var name = values[0];
        var site = parseInt(values[1], 10);
        var building = parseInt(values[2], 10);
        var floor = parseInt(values[3], 10);
        var room = parseInt(values[4], 10);
        if (!name || !name.trim() || !checkEntryDataValidity(site, building, floor, room)) {
            continue;
        }

        applyEntry(name, site, building, floor, room, validEntryCount);
        validEntryCount++;
    }

    document.getElementById("phonebook_entry_count").value = validEntryCount;
    if (validEntryCount > 0) {
        document.getElementById("phonebook_save_enabled").checked = 1;
    }

    return validEntryCount > 0;
}

function checkEntryDataValidity(site, building, floor, room) {
    if (!isNaN(site) && !isNaN(building) && !isNaN(floor) && !isNaN(room)) {
        if (site < 1 || site > 99) {
            return false;
        }

        if (building < 0 || building >= 1000) {
            return false;
        }

        if (floor < 0 || floor >= 99) {
            return false;
        }

        if (room < 1 || room > 99) {
            return false;
        }

        return true;
    }

    return false;
}

function applyEntry(name, site, building, floor, room, row) {
    var id = convertDataToId(site, building, floor, room);
    document.getElementById("name_" + row).value = name;
    document.getElementById("id_" + row).value = id;
    document.getElementById("use_expanded_format_" + row).value = building >= 100 ? 1 : 0;
}

function convertDataToId(site, building, floor, room) {
    var id;
    if (building >= 100) {
        id = (site * 10000000) + (building * 10000) + (floor * 100) + room;
    } else {
        id = (site * 1000000) + (building * 10000) + (floor * 100) + room;
    }

    return id;
}